@@ -1,3 +1,7 @@
+// This file is part of the uutils coreutils package.
+//
+// For the full copyright and license information, please view the LICENSE
+// file that was distributed with this source code.
 //! Custom panic hooks that allow silencing certain types of errors.
 //!
 //! Use the [`mute_sigpipe_panic`] function to silence panics caused by
@@ -26,17 +30,17 @@ fn is_broken_pipe(info: &PanicInfo) -> bool {
 ///
 /// For background discussions on `SIGPIPE` handling, see
 ///
-/// * https://github.com/uutils/coreutils/issues/374
-/// * https://github.com/uutils/coreutils/pull/1106
-/// * https://github.com/rust-lang/rust/issues/62569
-/// * https://github.com/BurntSushi/ripgrep/issues/200
-/// * https://github.com/crev-dev/cargo-crev/issues/287
+/// * `<https://github.com/uutils/coreutils/issues/374>`
+/// * `<https://github.com/uutils/coreutils/pull/1106>`
+/// * `<https://github.com/rust-lang/rust/issues/62569>`
+/// * `<https://github.com/BurntSushi/ripgrep/issues/200>`
+/// * `<https://github.com/crev-dev/cargo-crev/issues/287>`
 ///
 pub fn mute_sigpipe_panic() {
     let hook = panic::take_hook();
     panic::set_hook(Box::new(move |info| {
         if !is_broken_pipe(info) {
-            hook(info)
+            hook(info);
         }
     }));
 }
